@@ -1,8 +1,8 @@
 package provide db 0.4.0
 
 package require sqlite3
-package require hook
-package require debug
+package require webapp::hook
+package require wa_debug
 package require wa_uuid
 
 namespace eval ::db {
@@ -25,9 +25,9 @@ namespace eval ::db {
 
 		for {::set retry 0} {$retry < 30} {incr retry} {
 			if {$retry == "0"} {
-				debug::log db "$sql"
+				wa_debug::log db "$sql"
 			} else {
-				debug::log db "(try $retry) $sql"
+				wa_debug::log db "(try $retry) $sql"
 			}
 
 			if {[catch {
@@ -63,7 +63,7 @@ namespace eval ::db {
 			return 1
 		}
 
-		hook::call db::disconnect::enter
+		webapp::hook::call db::disconnect::enter
 
 		_tryeval -nodisconnect "END TRANSACTION;"
 
@@ -72,9 +72,9 @@ namespace eval ::db {
 		}
 		::unset ::db::CACHEDBHandle
 
-		debug::log db "Disconnecting from SQLite3 database."
+		wa_debug::log db "Disconnecting from SQLite3 database."
 
-		hook::call db::disconnect::return 1
+		webapp::hook::call db::disconnect::return 1
 
 		return 1
 	}
@@ -88,9 +88,9 @@ namespace eval ::db {
 			return $::db::CACHEDBHandle
 		}
 
-		hook::call db::connect::enter
+		webapp::hook::call db::connect::enter
 
-		debug::log db "Connecting to the SQLite3 database."
+		wa_debug::log db "Connecting to the SQLite3 database."
 
 		::unset -nocomplain ::db::cachefields
 
@@ -114,7 +114,7 @@ namespace eval ::db {
 
 		_tryeval -nodisconnect "BEGIN TRANSACTION;"
 
-		hook::call db::connect::return $::db::CACHEDBHandle
+		webapp::hook::call db::connect::return $::db::CACHEDBHandle
 
 		return $::db::CACHEDBHandle
 	}
@@ -171,13 +171,13 @@ namespace eval ::db {
 			lappend fieldlist "$field $type($field)"
 		}
 
-		hook::call db::create::enter $dbname $newfields
+		webapp::hook::call db::create::enter $dbname $newfields
 
 		::set sqlstr "CREATE TABLE IF NOT EXISTS main.$dbname ([join $fieldlist {, }]);"
 
 		_tryeval $sqlstr
 
-		hook::call db::create::return 1 $dbname $newfields
+		webapp::hook::call db::create::return 1 $dbname $newfields
 
 		return 1
 	}
@@ -216,9 +216,9 @@ namespace eval ::db {
 		}
 
 		if {[info exists where]} {
-			hook::call db::set::enter $dbname $fielddata $where
+			webapp::hook::call db::set::enter $dbname $fielddata $where
 		} else {
-			hook::call db::set::enter $dbname $fielddata
+			webapp::hook::call db::set::enter $dbname $fielddata
 		}
 
 		::set ret 0
@@ -247,9 +247,9 @@ namespace eval ::db {
 		}
 
 		if {[info exists where]} {
-			hook::call db::set::return $ret $dbname $fielddata $where
+			webapp::hook::call db::set::return $ret $dbname $fielddata $where
 		} else {
-			hook::call db::set::return $ret $dbname $fielddata
+			webapp::hook::call db::set::return $ret $dbname $fielddata
 		}
 
 		return $ret
@@ -280,9 +280,9 @@ namespace eval ::db {
 		::unset wherework
 
 		if {[info exists fields]} {
-			hook::call db::unset::enter $dbname $where $fields
+			webapp::hook::call db::unset::enter $dbname $where $fields
 		} else {
-			hook::call db::unset::enter $dbname $where
+			webapp::hook::call db::unset::enter $dbname $where
 		}
 
 		if {[info exists fields]} {
@@ -304,9 +304,9 @@ namespace eval ::db {
 		}
 
 		if {[info exists fields]} {
-			hook::call db::unset::return $ret $dbname $where $fields
+			webapp::hook::call db::unset::return $ret $dbname $where $fields
 		} else {
-			hook::call db::unset::return $ret $dbname $where
+			webapp::hook::call db::unset::return $ret $dbname $where
 		}
 
 		return $ret
@@ -358,9 +358,9 @@ namespace eval ::db {
 		::set dbname [lindex $args $dbnameidx]
 
 		if {[info exists where]} {
-			hook::call db::get::enter $dbname $fields $allbool $where
+			webapp::hook::call db::get::enter $dbname $fields $allbool $where
 		} else {
-			hook::call db::get::enter $dbname $fields $allbool
+			webapp::hook::call db::get::enter $dbname $fields $allbool
 		}
 
 		if {[info exists where]} {
@@ -410,9 +410,9 @@ namespace eval ::db {
 		}
 
 		if {[info exists where]} {
-			hook::call db::get::return $ret $dbname $fields $allbool $where
+			webapp::hook::call db::get::return $ret $dbname $fields $allbool $where
 		} else {
-			hook::call db::get::return $ret $dbname $fields $allbool
+			webapp::hook::call db::get::return $ret $dbname $fields $allbool
 		}
 
 		return $ret
