@@ -1,11 +1,12 @@
 package provide user 0.1
 
 package require db
-package require hook
+package require webapp::hook
 package require crypt
 package require wa_uuid
 package require module
 package require session
+package require wa_debug
 
 wa_uuid::register 11 user
 
@@ -20,7 +21,7 @@ namespace eval user {
 	#	0 is returned if no user exists.
 	# Stat: Complete
 	proc getuid {{username ""}} {
-		hook::call user::getuid::enter $username
+		webapp::hook::call user::getuid::enter $username
 
 		if {$username == ""} {
 			if {[info exists ::session::vars(uid)]} {
@@ -35,7 +36,7 @@ namespace eval user {
 			return 0
 		}
 
-		hook::call user::getuid::return $uid $username
+		webapp::hook::call user::getuid::return $uid $username
 
 		return $uid
 	}
@@ -47,11 +48,11 @@ namespace eval user {
 	#	An empty string is returned if the user does not exist.
 	# Stat: Complete
 	proc getnam {uid} {
-		hook::call user::getnam::enter $uid
+		webapp::hook::call user::getnam::enter $uid
 
 		set username [get -uid $uid -user]
 
-		hook::call user::getnam::return $username $uid
+		webapp::hook::call user::getnam::return $username $uid
 
 		return $username
 	}
@@ -65,38 +66,38 @@ namespace eval user {
 	# Stat: In progress.
 	proc login {uid pass from} {
 		if {![exists $uid]} {
-			debug::log user::login "User doesn't exist ($uid)"
+			wa_debug::log user::login "User doesn't exist ($uid)"
 			return 0
 		}
 
-		hook::call user::login $uid $pass $from
+		webapp::hook::call user::login $uid $pass $from
 
 		set hash [get -uid $uid -pass]
 
 		if {![::crypt::compare $pass $hash]} {
-			debug::log user::login "Failed password"
+			wa_debug::log user::login "Failed password"
 
 			set retval 0
 
-			hook::call user::login::return $uid $pass $from $retval
+			webapp::hook::call user::login::return $uid $pass $from $retval
 
-			debug::log user::login "Login for $uid, returning $retval"
+			wa_debug::log user::login "Login for $uid, returning $retval"
 
 			return $retval
 		}
 
 		set seturet [user::setuid $uid 1]
 		if {$seturet == 0} {
-			debug::log user::login "Could not setuid !"
+			wa_debug::log user::login "Could not setuid !"
 
 			set retval 0
 		} else {
 			set retval 1
 		}
 
-		hook::call user::login::return $uid $pass $from $retval
+		webapp::hook::call user::login::return $uid $pass $from $retval
 
-		debug::log user::login "Login for $uid, returning $retval"
+		wa_debug::log user::login "Login for $uid, returning $retval"
 
 		return $retval
 	}
@@ -113,7 +114,7 @@ namespace eval user {
 	proc create args {
 		# Require admin to create a user.
 		if {![hasflag "admin"]} {
-			debug::log user::create "Attempting to create user without admin flag!"
+			wa_debug::log user::create "Attempting to create user without admin flag!"
 			return 0
 		}
 
@@ -155,35 +156,35 @@ namespace eval user {
 		set user [lindex $args $useridx]
 
 		if {$user == ""} {
-			debug::log user::create "User specified as blank!"
+			wa_debug::log user::create "User specified as blank!"
 			return 0
 		}
 
 		# Require the root flag to set the root flag.
 		if {[lsearch -exact $flags "root"] != -1 && ![hasflag "root"]} {
-			debug::log user::create "Non-root user tried to create root user!"
+			wa_debug::log user::create "Non-root user tried to create root user!"
 			return 0
 		}
 
 		# Verify that the user does not already exist
 		set check [db::get -dbname user -field uid -where user=$user]
 		if {$check != ""} {
-			debug::log user::create "Tried to create user with existing username!"
+			wa_debug::log user::create "Tried to create user with existing username!"
 			return 0
 		}
 
-		hook::call user::create::enter $user $name $flags $opts $pass
+		webapp::hook::call user::create::enter $user $name $flags $opts $pass
 
 		set uid [wa_uuid::gen user]
 
 		set success [db::set -dbname user -field uid $uid -field user $user -field name $name -field flags $flags -field opts $opts -field pass $pass]
 
 		if {!$success} {
-			debug::log user::create "Failed to update database while creating user."
+			wa_debug::log user::create "Failed to update database while creating user."
 			return 0
 		}
 
-		hook::call user::create::return $uid $user $name $flags $opts $pass
+		webapp::hook::call user::create::return $uid $user $name $flags $opts $pass
 
 		return $uid
 	}
@@ -207,11 +208,11 @@ namespace eval user {
 		# Invalidate cache
 		unset -nocomplain ::user::cache_get
 
-		hook::call user::delete::enter $uid
+		webapp::hook::call user::delete::enter $uid
 
 		set success [db::unset -dbname user -where uid=$uid]
 
-		hook::call user::delete::return $success $uid
+		webapp::hook::call user::delete::return $success $uid
 
 		return $success
 	}
@@ -253,7 +254,7 @@ namespace eval user {
 		# Invalidate cache
 		unset -nocomplain ::user::cache_get
 
-		hook::call user::create::enter $uid $args
+		webapp::hook::call user::create::enter $uid $args
 
 		set ret 1
 
@@ -305,7 +306,7 @@ namespace eval user {
 			}
 		}
 
-		hook::call user::create::return $ret $uid $args
+		webapp::hook::call user::create::return $ret $uid $args
 
 		return $ret
 	}
@@ -396,12 +397,12 @@ namespace eval user {
 			set fieldscmd "-fields"
 		}
 
-		hook::call user::get::enter $uid $fields
+		webapp::hook::call user::get::enter $uid $fields
 
 		set ret [db::get -dbname user $wherecmd uid=$uid $fieldscmd $fields]
 		set ::user::cache_get($args) $ret
 
-		hook::call user::get::return $ret $uid $fields
+		webapp::hook::call user::get::return $ret $uid $fields
 
 		return $ret
 	}
@@ -423,7 +424,7 @@ namespace eval user {
 			set flags $uid
 		}
 
-		hook::call user::hasflag::enter $uid $chkflags
+		webapp::hook::call user::hasflag::enter $uid $chkflags
 
 		set rootchk [lsearch -exact $flags root]
 
@@ -433,12 +434,12 @@ namespace eval user {
 				set found 0
 			}
 			if {$found == -1} {
-				hook::call user::hasflag::return 0 $uid $chkflags
+				webapp::hook::call user::hasflag::return 0 $uid $chkflags
 				return 0
 			}
 		}
 
-		hook::call user::hasflag::return 1 $uid $chkflags
+		webapp::hook::call user::hasflag::return 1 $uid $chkflags
 
 		return 1
 	}
@@ -455,7 +456,7 @@ namespace eval user {
 			set uid [getuid]
 		}
 
-		hook::call user::setflag::enter $uid $newflags
+		webapp::hook::call user::setflag::enter $uid $newflags
 
 		set flags [string tolower [get -uid $uid -flags]]
 
@@ -480,7 +481,7 @@ namespace eval user {
 			set ret 0
 		}
 
-		hook::call user::setflag::return $ret $uid $newflags $flags
+		webapp::hook::call user::setflag::return $ret $uid $newflags $flags
 
 		return $ret
 	}
@@ -496,7 +497,7 @@ namespace eval user {
 			set uid [getuid]
 		}
 
-		hook::call user::unsetflag::enter $uid $delflags
+		webapp::hook::call user::unsetflag::enter $uid $delflags
 
 		set flags [string tolower [get -uid $uid -flags]]
 
@@ -528,7 +529,7 @@ namespace eval user {
 			set ret 0
 		}
 
-		hook::call user::unsetflag::return $uid $delflags $newflags
+		webapp::hook::call user::unsetflag::return $uid $delflags $newflags
 
 		return $ret
 	}
@@ -634,7 +635,7 @@ namespace eval user {
 	# Rets: 1 if the user exists, 0 otherwise
 	# Stat: Complete
 	proc exists {uid} {
-		hook::call user::exists::enter $uid
+		webapp::hook::call user::exists::enter $uid
 
 		set ret 1
 
@@ -644,7 +645,7 @@ namespace eval user {
 			set ret 0
 		}
 
-		hook::call user::exists::return $ret $uid
+		webapp::hook::call user::exists::return $ret $uid
 
 		return $ret
 	}
@@ -655,7 +656,7 @@ namespace eval user {
 	# Rets: A list of UIDs for users who have the flag specified.
 	# Stat: Complete
 	proc listflag {flag} {
-		hook::call user::listflag::enter $flag
+		webapp::hook::call user::listflag::enter $flag
 
 		set isbad [info exists ::user::badflag($flag)]
 
@@ -675,7 +676,7 @@ namespace eval user {
 			}
 		}
 
-		hook::call user::listflag::enter $ret $flag
+		webapp::hook::call user::listflag::enter $ret $flag
 
 		return $ret
 	}
@@ -717,9 +718,9 @@ namespace eval user {
 	# Stat: In progress
 	proc setuid {newuid {override 0}} {
 		if {[info exists ::session::vars(uid)]} {
-			debug::log user::setuid "Asked to setuid to $newuid, from $::session::vars(uid)"
+			wa_debug::log user::setuid "Asked to setuid to $newuid, from $::session::vars(uid)"
 		} else {
-			debug::log user::setuid "Asked to setuid to $newuid, from nothing"
+			wa_debug::log user::setuid "Asked to setuid to $newuid, from nothing"
 		}
 
 		if {$newuid == 0} {
